@@ -69,9 +69,9 @@ sub SimpleUpdateFromSelect {
     return $sth unless $sth;
 
     my (@binds, @columns);
-    while ( my ($k, $v) = each %$values ) {
+    for my $k (sort keys %$values) {
         push @columns, $k;
-        push @binds, $v;
+        push @binds, $values->{$k};
     }
 
     my $update_query = "UPDATE $table SET "
@@ -282,6 +282,13 @@ sub ConvertTimezoneFunction {
     return "CONVERT_TZ( $args{'Field'}, $args{'From'}, $args{'To'} )";
 }
 
+sub _DateTimeIntervalFunction {
+    my $self = shift;
+    my %args = ( From => undef, To => undef, @_ );
+
+    return "TIMESTAMPDIFF(SECOND, $args{'From'}, $args{'To'})";
+}
+
 1;
 
 __END__
